@@ -2,7 +2,7 @@
 #
 #   arc:
 #     - selection colors are all blue.
-#     - button highlight color matches theme better.
+#     - button focus uses blue color rather than focus ring.
 #
 
 set ap [file normalize [file dirname [info script]]]
@@ -59,6 +59,7 @@ namespace eval ::ttk::theme::awarc {
     set colors(tab.inactive) $colors(bg.dark)
     set colors(border.button.active) $colors(bg.darker)
     set colors(button.anchor) {}
+    set colors(button.active) $colors(bg.lightest)
     set colors(notebook.tab.focusthickness) 3
     set colors(notebook.tab.padding) {3 0}
     set colors(button.image.padding) {6 3}
@@ -91,9 +92,18 @@ namespace eval ::ttk::theme::awarc {
 
   proc init { } {
     set theme awarc
-    set version 1.5
-    if { ([info exists ::notksvg] && $::notksvg) ||
-        [catch {package present tksvg}] } {
+    set version 1.6.1
+    try {
+      set ti [image create photo -data {<svg></svg>} -format svg]
+      image delete $ti
+      set havetksvg true
+    } on error {err res} {
+      lassign [dict get $res -errorcode] a b c d
+      if { $c ne "PHOTO_FORMAT" } {
+        set havetksvg true
+      }
+    }
+    if { ([info exists ::notksvg] && $::notksvg) || ! $havetksvg } {
       namespace delete ::ttk::theme::${theme}
       error "no tksvg package present: cannot load scalable ${theme} theme"
     }
