@@ -59,28 +59,30 @@ namespace eval ::ttk::theme::awbreeze {
     set colors(graphics.color.alternate) \
         [::colorutils::opaqueBlendPerc $colors(graphics.color) #ffffff 0.7 2]
 
-    set colors(entrybg.checkbutton) $colors(bg.bg)
-    set colors(button.pressed) $colors(graphics.color)
+    set colors(active.color) $colors(graphics.color.alternate)
+    set colors(arrow.color) $colors(bg.darkest)
     set colors(border.button.active) $colors(graphics.color)
+    set colors(border.checkbutton) $colors(graphics.color)
     set colors(button.active.focus) $colors(graphics.color.alternate)
     set colors(button.anchor) {}
     set colors(button.image.padding) {6 4}
     set colors(button.padding) {8 3}
-    set colors(border.checkbutton) $colors(graphics.color)
+    set colors(button.pressed) $colors(graphics.color)
     set colors(checkbutton.focusthickness) 1
-    set colors(checkbutton.padding) {4 0 0 2}
-    set colors(combobox.entry.image.padding) {6 8}
+    set colors(checkbutton.padding) {4 3 0 3}
+    set colors(combobox.entry.image.padding) {6 7}
     set colors(entrybg.bg) #fcfcfc
+    set colors(entrybg.checkbutton) $colors(bg.bg)
     set colors(entry.image.padding) {5 8}
     set colors(entry.padding) {2 0}
-    set colors(arrow.color) $colors(bg.darkest)
-    set colors(spinbox.color.arrow) $colors(bg.darkest)
     set colors(menubutton.padding) {10 2}
     set colors(menubutton.use.button.image) true
+    set colors(notebook.tab.focusthickness) 4
     set colors(parent.theme) default
     set colors(scale.trough)  $colors(graphics.color)
     set colors(scrollbar.has.arrows) false
     set colors(select.bg) $colors(graphics.color)
+    set colors(spinbox.color.arrow) $colors(bg.darkest)
     set colors(spinbox.image.padding) {4 4}
     set colors(toolbutton.image.padding) {10 7}
     set colors(toolbutton.use.button.image) true
@@ -90,9 +92,18 @@ namespace eval ::ttk::theme::awbreeze {
 
   proc init { } {
     set theme awbreeze
-    set version 1.8
-    if { ([info exists ::notksvg] && $::notksvg) ||
-        [catch {package present tksvg}] } {
+    set version 1.9.1
+    try {
+      set ti [image create photo -data {<svg></svg>} -format svg]
+      image delete $ti
+      set havetksvg true
+    } on error {err res} {
+      lassign [dict get $res -errorcode] a b c d
+      if { $c ne "PHOTO_FORMAT" } {
+        set havetksvg true
+      }
+    }
+    if { ([info exists ::notksvg] && $::notksvg) || ! $havetksvg } {
       namespace delete ::ttk::theme::${theme}
       error "no tksvg package present: cannot load scalable ${theme} theme"
     }
