@@ -44,7 +44,8 @@ proc main { } {
   ::themeutils::setThemeColors $theme \
       scale.factor $sf
 
-  if { ! $::notksvg } {
+  if { ! $::notksvg &&
+      [package vcompare 8.6.99 $::tk_version] > 0 } {
     catch { package require tksvg }
   }
 
@@ -77,8 +78,19 @@ proc main { } {
     }
   }
 
-  set havetksvg true
-  if { [catch {package present tksvg}] } {
+  set havetksvg false
+  try {
+    set ti [image create photo -data {<svg></svg>} -format svg]
+    image delete $ti
+    set havetksvg true
+  } on error {err res} {
+    lassign [dict get $res -errorcode] a b c d
+    if { $c ne "PHOTO_FORMAT" } {
+      set havetksvg true
+    }
+  }
+
+  if { ! $havetksvg } {
     error "tksvg is required"
   }
 
